import * as React from 'react';
import { List, ListItem, makeSelectable } from 'material-ui/List';
import Subheader from 'material-ui/Subheader';
import Paper from 'material-ui/Paper';
import { OFRest } from '../../components/Rest';
import * as Utils from '../../components/Utils';
import RaisedButton from 'material-ui/RaisedButton';
import {
  Table,
  TableBody,
  TableHeader,
  TableHeaderColumn,
  TableFooter,
  TableRow,
  TableRowColumn,
} from 'material-ui/Table';
import { SensorConfigPopup } from '../../containers/config/SensorConfigPopup';

export class TargetList extends React.Component<any, any> {
  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      selected: [],
      targets: [],
      startConfig: false,
    };
  }

  componentWillMount() {
    this.getTargetList();
  }

  getTargetList() {
    let obj: any;
    obj = {
      "id": "0",
      "member": {
        "id": "1"
      }
    };

    let os: OFRest = new OFRest("Target", "List", obj);
    var that: any = this;
    os.Call().then(function (res) {
      return res.json();
    }).then(function (json) {
      let targetList = JSON.parse(json.resultStr);
      that.setState({
        targets: targetList,
      });
    }).catch(function (err) {
      console.log(err);
    });
  }


  handleRowSelection = (selectedRows: any) => {
    this.setState({
      selected: selectedRows,
    });
  }


  handleNext = () => {
    if (this.state.selected.length === 0) {
      alert('Select a target to monitor');
    } else {
      this.setState({
        startConfig: true,
      });
    }
  }
  handleDetail = () => {
    if (this.state.selected.length === 0) {
      alert('Select a target to monitor');
    } else {
      this.props.history.push('/target/targetDetail');
    }
  }

  isSelected = (index: any) => {
    if (this.state.selected.indexOf(index) === -1) {
      return false;
    } else {
      return true;
    }
  }
  handleConfigCancel = () => {
    this.setState({
      startConfig: false,
    });
  }
  showSensorConfigPopup = () => {
    if (this.state.startConfig) {
      return <SensorConfigPopup open={this.state.startConfig} onCancel={this.handleConfigCancel} target={this.state.targets[this.state.selected[0]]}/>;
    }
    return null;
  }

  render() {
    return (
      <div >
        {this.showSensorConfigPopup()}
        <Table
          selectable={true}
          multiSelectable={false}
          onRowSelection={this.handleRowSelection.bind(this)}
        >
          <TableHeader
            adjustForCheckbox={false}
            enableSelectAll={false}
            displaySelectAll={true}>
            <TableRow >
              <TableHeaderColumn >Host</TableHeaderColumn>
              <TableHeaderColumn >Port</TableHeaderColumn>
              <TableHeaderColumn >Type</TableHeaderColumn>
              <TableHeaderColumn >Kind</TableHeaderColumn>
              <TableHeaderColumn >Name</TableHeaderColumn>
              <TableHeaderColumn >Version</TableHeaderColumn>
            </TableRow>
          </TableHeader>
          <TableBody
            deselectOnClickaway={false}>
            displayRowCheckbox={true}
            >
            {this.state.targets.map((row: any, index: number) => (
              <TableRow key={index}
                selected={this.isSelected(index)}
              >
                <TableRowColumn>{Utils.int2ip(row.ip)}</TableRowColumn>
                <TableRowColumn>{row.port}</TableRowColumn>
                <TableRowColumn>{row.targetType}</TableRowColumn>
                <TableRowColumn>{row.kinds}</TableRowColumn>
                <TableRowColumn>{row.vendorName}</TableRowColumn>
                <TableRowColumn>{row.version}</TableRowColumn>
              </TableRow>
            ))};

            </TableBody>
        </Table>

        <RaisedButton label="New Sensor" primary={true} onClick={this.handleNext.bind(this)} style={{ margin: 20 }} />
        <RaisedButton label="Detail" primary={true} onClick={this.handleDetail.bind(this)} style={{ margin: 20 }} />
      </div>
    );
  }
}
